# coding: utf-8

"""
    Carbon DLS API

    Welcome to the Carbon DLS API docs!  You can find all relevant documentation here: https://github.com/carbon3d/carbon3d-api   # noqa: E501

    The version of the OpenAPI document: 0.0.7
    Contact: api-list@carbon3d.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import carbon3d
from carbon3d.api.orders_api import OrdersApi  # noqa: E501
from carbon3d.rest import ApiException


class TestOrdersApi(unittest.TestCase):
    """OrdersApi unit test stubs"""

    def setUp(self):
        self.api = carbon3d.api.orders_api.OrdersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_order(self):
        """Test case for create_order

        Create an Order  # noqa: E501
        """
        pass

    def test_delete_order(self):
        """Test case for delete_order

        Cancel an Order  # noqa: E501
        """
        pass

    def test_get_order(self):
        """Test case for get_order

        Get an Order  # noqa: E501
        """
        pass

    def test_get_orders(self):
        """Test case for get_orders

        Fetch orders  # noqa: E501
        """
        pass

    def test_update_order(self):
        """Test case for update_order

        Update an Order  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    Carbon DLS API

    Welcome to the Carbon DLS API docs!  You can find all relevant documentation here: https://github.com/carbon3d/carbon3d-api   # noqa: E501

    The version of the OpenAPI document: 0.0.7
    Contact: api-list@carbon3d.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from carbon3d.models.build import Build
from carbon3d.models.build_attachments import BuildAttachments
from carbon3d.models.builds_response import BuildsResponse
from carbon3d.models.model import Model
from carbon3d.models.models_response import ModelsResponse
from carbon3d.models.order import Order
from carbon3d.models.order_request import OrderRequest
from carbon3d.models.order_request_parts import OrderRequestParts
from carbon3d.models.order_update_request import OrderUpdateRequest
from carbon3d.models.orders_response import OrdersResponse
from carbon3d.models.orders_response_orders import OrdersResponseOrders
from carbon3d.models.part import Part
from carbon3d.models.part_genealogy import PartGenealogy
from carbon3d.models.part_genealogy_build_info import PartGenealogyBuildInfo
from carbon3d.models.part_genealogy_print_info import PartGenealogyPrintInfo
from carbon3d.models.part_order import PartOrder
from carbon3d.models.part_order_request import PartOrderRequest
from carbon3d.models.part_order_status import PartOrderStatus
from carbon3d.models.part_order_update_request import PartOrderUpdateRequest
from carbon3d.models.part_orders_response import PartOrdersResponse
from carbon3d.models.part_orders_response_part_orders import PartOrdersResponsePartOrders
from carbon3d.models.part_request import PartRequest
from carbon3d.models.parts_response import PartsResponse
from carbon3d.models.print_order import PrintOrder
from carbon3d.models.print_order_request import PrintOrderRequest
from carbon3d.models.print_order_routed_to import PrintOrderRoutedTo
from carbon3d.models.print_order_update_request import PrintOrderUpdateRequest
from carbon3d.models.print_ref import PrintRef
from carbon3d.models.printed_part import PrintedPart
from carbon3d.models.printed_part_ref import PrintedPartRef
from carbon3d.models.printed_part_status import PrintedPartStatus
from carbon3d.models.printed_parts_response import PrintedPartsResponse
from carbon3d.models.printer import Printer
from carbon3d.models.printer_prints import PrinterPrints
from carbon3d.models.printer_status import PrinterStatus
from carbon3d.models.printers_response import PrintersResponse
from carbon3d.models.prints_response import PrintsResponse
